@@ -11,7 +11,7 @@ import {
     ILsystemScene,
     ITaskResult, IPGLProgressState
 } from './interfaces';
-import { THREE, disposeScene, meshify } from './utilities';
+import { THREE, OrbitControls, disposeScene, meshify } from './utilities';
 import { SCALES, LsystemUnit } from './consts';
 
 export class PGLWidgetView extends DOMWidgetView {
@@ -39,7 +39,6 @@ export class PGLWidgetView extends DOMWidgetView {
 
     pglProgressState: IPGLProgressState = null;
 
-    disposables: THREE.Scene[] = [];
     isDetached = false;
 
     initialize(parameters: WidgetView.InitializeParameters) {
@@ -158,7 +157,7 @@ export class PGLWidgetView extends DOMWidgetView {
         this.renderer.shadowMap.type = THREE.PCFSoftShadowMap;
         this.renderer.render(this.scene, this.camera);
 
-        this.orbitControl = new THREE.OrbitControls(this.camera, this.renderer.domElement);
+        this.orbitControl = new OrbitControls(this.camera, this.renderer.domElement);
         this.orbitControl.enableZoom = true;
         this.orbitControl.addEventListener('change', () => {
             this.renderer.render(this.scene, this.camera)
@@ -184,8 +183,6 @@ export class PGLWidgetView extends DOMWidgetView {
                             window.cancelAnimationFrame(id)
                         }
                         const [x, y, z] = this.camera.position.toArray();
-                        console.log(x, y, Math.sqrt(Math.pow(Math.abs(x), 2) + Math.pow(Math.abs(y), 2)));
-
                         this.orbitControl.update();
                         this.renderer.render(this.scene, this.camera);
                     };
@@ -358,6 +355,10 @@ export class PGLWidgetView extends DOMWidgetView {
 
 export class SceneWidgetView extends PGLWidgetView {
 
+    decoding = [];
+    in = 0;
+    out = 0;
+
     initialize(parameters: WidgetView.InitializeParameters) {
         super.initialize(parameters);
     }
@@ -370,18 +371,35 @@ export class SceneWidgetView extends PGLWidgetView {
         });
     }
 
+    updateProgress() {
+        this.pglProgressState.busy = 1 - (this.out / this.in);
+    }
+
     setScenes(scenes: IScene[]) {
 
+        // TODO: add option to decode in sequence
         for (let i = 0; i < scenes.length; i++) {
             const scene = scenes[i];
-            if(!this.scene.getObjectByName(scene.id)) {
+            // ignore scenes that are already rendered or still being decoded
+            if(!this.scene.getObjectByName(scene.id) && !(this.decoding.indexOf(scene.id) > -1)) {
                 const { id, data, position, scale } = scene;
+                this.decoding.push(id);
+                this.in++;
+                this.updateProgress();
                 decoder.decode({ data: data.buffer, userData: { position, scale, id } })
                     .then(result => {
+                        this.out++;
+                        this.updateProgress();
+
                         const scene = new THREE.Scene();
                         const { geoms: results, userData: { position, scale, id } } = result;
                         const [x, y, z] = position;
 
+                        this.decoding.splice(this.decoding.indexOf(scene.id));
+                        const toRemove = this.scene.children.filter(obj => {
+                            return obj instanceof THREE.Scene && !scenes.some(scene => scene.id === obj.name)
+                        })
+
                         if (results.length > 0) {
                             scene.add(...meshify(results, {
                                 flatShading: this.pglControlsState.flatShading,
@@ -390,12 +408,18 @@ export class SceneWidgetView extends PGLWidgetView {
                             scene.name = id;
                             scene.position.set(x, y, z);
                             scene.scale.multiplyScalar(scale);
+                            toRemove.forEach(scene => scene.visible = false);
 
                             this.scene.add(scene);
-                            this.disposables.push(scene);
                             this.renderer.render(this.scene, this.camera);
                             this.orbitControl.update();
                         }
+
+                        // clear scenes already rendered but not in new scenes array
+                        this.renderer.render(this.scene, this.camera);
+                        this.scene.remove(...toRemove);
+                        toRemove.forEach(scene => disposeScene(scene as THREE.Scene));
+
                     })
                     .catch(err => console.log(err));
             }
@@ -405,7 +429,11 @@ export class SceneWidgetView extends PGLWidgetView {
 
     remove() {
         // TODO: dispose helpers etc.?
-        this.disposables.forEach(scene => disposeScene(scene));
+        this.scene.children.forEach(child => {
+            if (child instanceof THREE.Scene) {
+                disposeScene(child)
+            }
+        })
         super.remove();
     }
 
@@ -639,6 +667,11 @@ export class LsystemWidgetView extends PGLWidgetView {
     }
 
     remove() {
+        this.scene.children.forEach(child => {
+            if (child instanceof THREE.Scene) {
+                disposeScene(child)
+            }
+        })
         super.remove();
     }
 
